Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(138)

Unified Diff: ui/views/animation/scroll_animator.h

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/animation/bounds_animator_unittest.cc ('k') | ui/views/animation/scroll_animator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/animation/scroll_animator.h
diff --git a/ui/views/animation/scroll_animator.h b/ui/views/animation/scroll_animator.h
index 35e159bc552ecf33d93975376e57f344713a552d..525a99801f574af663d1c91703982df44e104144 100644
--- a/ui/views/animation/scroll_animator.h
+++ b/ui/views/animation/scroll_animator.h
@@ -7,10 +7,10 @@
#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
-#include "ui/base/animation/animation_delegate.h"
+#include "ui/gfx/animation/animation_delegate.h"
#include "ui/views/views_export.h"
-namespace ui {
+namespace gfx {
class SlideAnimation;
}
@@ -25,7 +25,7 @@ class VIEWS_EXPORT ScrollDelegate {
~ScrollDelegate() {}
};
-class VIEWS_EXPORT ScrollAnimator : public ui::AnimationDelegate {
+class VIEWS_EXPORT ScrollAnimator : public gfx::AnimationDelegate {
public:
// The ScrollAnimator does not own the delegate. Uses default acceleration.
explicit ScrollAnimator(ScrollDelegate* delegate);
@@ -40,10 +40,10 @@ class VIEWS_EXPORT ScrollAnimator : public ui::AnimationDelegate {
bool is_scrolling() const { return !!animation_.get(); }
private:
- // Implementation of ui::AnimationDelegate.
- virtual void AnimationEnded(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationCanceled(const ui::Animation* animation) OVERRIDE;
+ // Implementation of gfx::AnimationDelegate.
+ virtual void AnimationEnded(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationProgressed(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationCanceled(const gfx::Animation* animation) OVERRIDE;
ScrollDelegate* delegate_;
@@ -53,7 +53,7 @@ class VIEWS_EXPORT ScrollAnimator : public ui::AnimationDelegate {
float duration_;
float acceleration_;
- scoped_ptr<ui::SlideAnimation> animation_;
+ scoped_ptr<gfx::SlideAnimation> animation_;
DISALLOW_COPY_AND_ASSIGN(ScrollAnimator);
};
« no previous file with comments | « ui/views/animation/bounds_animator_unittest.cc ('k') | ui/views/animation/scroll_animator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698